@@ -31,11 +31,14 @@ import cStringIO
 import httplib
 import struct
 import string
+import time
 
 # Local
 from g import *
 from codes import *
 import utils
+import services
+import os_utils
 import status
 import pml
 import status
@@ -528,7 +531,6 @@ def probeDevices(bus=DEFAULT_PROBE_BUS, timeout=10,
                 bn = hpmudext.HPMUD_BUS_USB
 
             result_code, data = hpmudext.probe_devices(bn)
-
             if result_code == hpmudext.HPMUD_R_OK:
                 for x in data.splitlines():
                     m = direct_pat.match(x)
@@ -1307,6 +1309,9 @@ class Device(object):
     def openLEDM(self):
         return self.__openChannel(hpmudext.HPMUD_S_LEDM_SCAN)
 
+    def openMarvell_EWS(self):
+        return self.__openChannel(hpmudext.HPMUD_S_MARVELL_EWS_CHANNEL)
+
     def closePrint(self):
         return self.__closeChannel(hpmudext.HPMUD_S_PRINT_CHANNEL)
 
@@ -1334,6 +1339,9 @@ class Device(object):
     def closeLEDM(self):
         return self.__closeChannel(hpmudext.HPMUD_S_LEDM_SCAN)
 
+    def closeMarvell_EWS(self):
+        return self.__closeChannel(hpmudext.HPMUD_S_MARVELL_EWS_CHANNEL)
+
     def openCfgUpload(self):
         return self.__openChannel(hpmudext.HPMUD_S_CONFIG_UPLOAD_CHANNEL)
 
@@ -1829,13 +1837,13 @@ class Device(object):
                             dynamic_sku_data = True
                             break
                     except:
-                        pass                                 
+                        pass
 
                 a, aa = 1, 1
                 while True:
                     if dynamic_sku_data:
                         if a > len(agents):
-                            break 
+                            break
                         agent = agents[a-1]
                         mq_agent_sku = agent['agent-sku']
                         agent_kind = agent['kind']
@@ -2146,6 +2154,9 @@ class Device(object):
     def readLEDM(self, bytes_to_read, stream=None, timeout=prop.read_timeout, allow_short_read=True):
         return self.__readChannel(self.openLEDM, bytes_to_read, stream, timeout, allow_short_read)
 
+    def readMarvell_EWS(self, bytes_to_read, stream=None, timeout=prop.read_timeout, allow_short_read=True):
+        return self.__readChannel(self.openMarvell_EWS, bytes_to_read, stream, timeout, allow_short_read)
+
     def readSoapFax(self, bytes_to_read, stream=None, timeout=prop.read_timeout, allow_short_read=True):
         return self.__readChannel(self.openSoapFax, bytes_to_read, stream, timeout, allow_short_read)
 
@@ -2232,6 +2243,9 @@ class Device(object):
     def writeLEDM(self, data):
         return self.__writeChannel(self.openLEDM, data)
 
+    def writeMarvell_EWS(self, data):
+        return self.__writeChannel(self.openMarvell_EWS, data)
+
     def writeCfgDownload(self, data):
         return self.__writeChannel(self.openCfgDownload, data)
 
@@ -2369,8 +2383,7 @@ class Device(object):
                 else:
                     c = 'lp -c -d%s %s %s' % (printer_name, lp_opt, file_name)
 
-                log.debug(c)
-                exit_code = os.system(c)
+                exit_code = os_utils.execute(c)
 
                 if exit_code != 0:
                     log.error("Print command failed with exit code %d!" % exit_code)
@@ -2388,8 +2401,7 @@ class Device(object):
                 else:
                     c = 'lpr -P%s %s %s %s' % (printer_name, raw_str, rem_str, file_name)
 
-                log.debug(c)
-                exit_code = os.system(c)
+                exit_code = os_utils.execute(c)
 
                 if exit_code != 0:
                     log.error("Print command failed with exit code %d!" % exit_code)
@@ -2518,7 +2530,7 @@ class Device(object):
         if data:
             data = data.split('\r\n\r\n', 1)[1]
             if data:
-                data = status.clean(data)
+                data = status.ExtractXMLData(data)
         return data
 
 #-------------------------For LEDM SOAP PROTOCOL(FAX) Devices----------------------------------------------------------------------#
@@ -2532,7 +2544,7 @@ class Device(object):
         if data:
             data = data.split('\r\n\r\n', 1)[1]
             if data:
-                data = status.clean(data)
+                data = status.ExtractXMLData(data)
         return data
 
     def readAttributeFromXml_EWS(self, uri, attribute):
@@ -2542,8 +2554,10 @@ class Device(object):
             log.error("Unable To read the XML data from device")
             return ""
         xmlDict = utils.XMLToDictParser().parseXML(data)
+
         try:
-            return str(xmlDict[attribute])
+            #return str(xmlDict[attribute])
+            return xmlDict[attribute]
         except:
             return str("")
 
@@ -2557,10 +2571,11 @@ class Device(object):
             return ""
         xmlDict = utils.XMLToDictParser().parseXML(data)
         try:
-            return str(xmlDict[attribute])
+            return xmlDict[attribute]
         except:
             return str("")
 
+
     def downloadFirmware(self, usb_bus_id=None, usb_device_id=None): # Note: IDs not currently used
         ok = False
         filename = os.path.join(prop.data_dir, "firmware", self.model.lower() + '.fw.gz')
@@ -2657,12 +2672,43 @@ class LocalOpenerEWS_LEDM(urllib.URLopener):
 
         reply = xStringIO()
 
-        while dev.readEWS_LEDM(512, reply, timeout=3):
-            pass
+        #while dev.readEWS_LEDM(512, reply, timeout=3):
+            #pass
+
+        END_OF_DATA="0\r\n\r\n"
+        bytes_requested = 1024
+        bytes_remaining = 0
+        chunkedFlag = True
+
+        bytes_read = dev.readEWS_LEDM(bytes_requested, reply, timeout=3)
+
+        for line in reply.getvalue().splitlines():
+            if line.lower().find("content-length") != -1:
+                 bytes_remaining = int(line.split(":")[1])
+                 chunkedFlag = False
+                 break
+
+        xml_data_start = reply.getvalue().find("<?xml")
+        if (xml_data_start != -1):
+            bytes_remaining = bytes_remaining - (len(reply.getvalue())  - xml_data_start)
+
+
+        while bytes_read > 0:
+            temp_buf = xStringIO()
+            bytes_read = dev.readEWS_LEDM(bytes_requested, temp_buf, timeout=3)
+            reply.write(temp_buf.getvalue())
+
+            if not chunkedFlag:     # Unchunked data
+                bytes_remaining = bytes_remaining - bytes_read
+                if bytes_remaining <= 0:
+                    break
+            elif END_OF_DATA == temp_buf.getvalue():   # Chunked data end
+                    break
 
         reply.seek(0)
         return reply.getvalue()
 
+
 # URLs: hp:/usb/HP_OfficeJet_7500?serial=00XXXXXXXXXX&loc=/hp/device/info_device_status.xml
 class LocalOpener_LEDM(urllib.URLopener):
     def open_hp(self, url, dev, foot=""):
@@ -2683,11 +2729,37 @@ class LocalOpener_LEDM(urllib.URLopener):
 
         reply = xStringIO()
 
-        while dev.readLEDM(512, reply, timeout=3):
-            pass
+        #while dev.readLEDM(512, reply, timeout=3):
+            #pass
+
+        END_OF_DATA="0\r\n\r\n"
+        bytes_requested = 1024
+        bytes_remaining = 0
+        chunkedFlag = True
+
+        bytes_read = dev.readLEDM(bytes_requested, reply, timeout=3)
+
+        for line in reply.getvalue().splitlines():
+            if line.lower().find("content-length") != -1:
+                 bytes_remaining = int(line.split(":")[1])
+                 chunkedFlag = False
+                 break
+
+        xml_data_start = reply.getvalue().find("<?xml")
+        if (xml_data_start != -1):
+            bytes_remaining = bytes_remaining - (len(reply.getvalue())  - xml_data_start)
+
+        while bytes_read > 0:
+            temp_buf = xStringIO()
+            bytes_read = dev.readLEDM(bytes_requested, temp_buf, timeout=3)
+            reply.write(temp_buf.getvalue())
+
+            if not chunkedFlag:     # Unchunked data
+                bytes_remaining = bytes_remaining - bytes_read
+                if bytes_remaining <= 0:
+                    break
+            elif END_OF_DATA == temp_buf.getvalue():   # Chunked data end
+                    break
 
         reply.seek(0)
         return reply.getvalue()
-
-
-
