@@ -28,6 +28,7 @@ Author: Naga Samrat Chowdary Narla, Sarbeswar Meher
 #include "hpmud.h"
 #include "hpmudi.h"
 #include <dlfcn.h>
+#include "utils.h"
 
 mud_device_vf __attribute__ ((visibility ("hidden"))) musb_mud_device_vf =
 {
@@ -2147,6 +2148,10 @@ enum HPMUD_RESULT hpmud_make_usb_uri(const char *busnum, const char *devnum, cha
 
 		if (!serial[0])
 			strcpy(serial, "0"); /* no serial number, make it zero */
+        if( is_interface(dev, 8))
+        {
+             strcpy(serial, "SMART_INSTALL_ENABLED"); /* no serial number, make it zero */
+        }
 	}
 	else
 	{
@@ -2199,71 +2204,4 @@ enum HPMUD_RESULT hpmud_make_usb_serial_uri(const char *sn, char *uri, int uri_s
 bugout:
 	return stat;
 }
-/*********HANDLING SMART INSTALL********/
 
-int disable_smartInstall(struct usb_device *dev, usb_dev_handle *hd, int Interface)
-{
-	// TBD:: not yet implemented.
-    BUG("HP Device acting like CD ROM (Smart Install is enabled), so prevent from functioning device using USB Cable.\n");
-    BUG("Please Refer following link to fix @ https://bugs.launchpad.net/hplip/+bug/1027004 ");
-    return 0;
-}
-
-int HandleSmartInstall()
-{
-	struct usb_bus *bus = NULL;
-	struct usb_device *dev = NULL;
-	struct usb_dev_handle *devh = NULL;
-	char imanufact[128] = {0,} , iproduct[128] = {0,}, iserial[128] ={0,};
-	int r ;
-
-	usb_init();
-	usb_find_busses();
-	usb_find_devices();
-
-	for (bus=usb_busses; bus; bus=bus->next)
-	{
-		for (dev=bus->devices; dev; dev=dev->next)
-		{
-			DBG("idVendor = %x bNumInterfaces=%d bInterfaceClass=%d\n",dev->descriptor.idVendor, dev->config[0].bNumInterfaces, dev->config[0].interface[0].altsetting[0].bInterfaceClass);
-			if (dev->descriptor.idVendor != 0x3f0) /*Not HP device*/
-				continue;
-
-			if (dev->config[0].bNumInterfaces != 1)
-				continue;
-
-			if (dev->config[0].interface[0].altsetting[0].bInterfaceClass == USB_CLASS_MASS_STORAGE)
-			{
-				DBG("usb_open  USB_CLASS_MASS_STORAGE\n");
-				devh = usb_open(dev);
-				if(!devh)
-				{
-					BUG("Invalid usb_open: %m\n");
-					continue;
-				}
-				/* Found HP device. */
-				if ((r=get_string_descriptor(devh, dev->descriptor.iProduct, iproduct, sizeof(iproduct))) < 0)
-					BUG("invalid product id string ret=%d\n", r);
-
-				if ((r=get_string_descriptor(devh, dev->descriptor.iSerialNumber, iserial, sizeof(iserial))) < 0)
-					BUG("invalid serial id string ret=%d\n", r);
-
-				if ((r=get_string_descriptor(devh, dev->descriptor.iManufacturer, imanufact, sizeof(imanufact))) < 0)
-					BUG("invalid manufacturer string ret=%d\n", r);
-
-				DBG("Manufacturer = %s\n",imanufact);
-				DBG("Product = %s\n",iproduct);
-				DBG("SerialNumber = %s\n",iserial);
-
-				//Select Laserjet Device only
-				if(strstr(iproduct,"LaserJet") || strstr(iproduct, "Laserjet"))
-				{
-					disable_smartInstall(dev, devh, dev->config[0].interface[0].altsetting[0].bInterfaceNumber);
-				}
-				usb_close(devh);
-				devh = NULL;
-			}
-		}
-	}
-	return 0;
-}
