@@ -54,6 +54,7 @@
 #include "hpip.h"
 #include "hpcupsfax.h"
 #include "bug.h"
+#include "utils.h"
 using namespace std;
 
 int    fax_encoding = RASTER_MMR;
@@ -65,7 +66,7 @@ uint32_t (*convert_endian_l)(uint32_t);
 uint16_t (*convert_endian_s)(uint16_t);
 
 static int iLogLevel = 1;
-char hpFileName[64] = "/tmp/hplipfaxLog_XXXXXX";
+char hpFileName[64] ;
 
 #define TIFF_HDR_SIZE 8
 #define LITTLE_ENDIAN_MODE I
@@ -439,20 +440,18 @@ int ProcessTiffData(int fromFD, int toFD)
     int bytes_written = 0;
     int ret_status = 0;
     int bytes_read = 0;
-    char hpTiffFileName[64] = "/tmp/hpliptiffXXXXXX";
+    char hpTiffFileName[64];
     long input_file_size = 0;
+    FILE* pFilePtrFax;
+    snprintf(hpTiffFileName,sizeof(hpTiffFileName), "%s/hpliptiffXXXXXX","/var/log/hp/tmp");
 
-    fdTiff = mkstemp (hpTiffFileName);
+
+//    fdTiff = mkstemp (hpTiffFileName);
+    fdTiff = createTempFile(hpTiffFileName, &pFilePtrFax);
     if (fdTiff < 0)
     {
-        DBG ("Warning: Unable to open Fax output file - %s for writing, so trying another location\n", hpTiffFileName);
-        strncpy(hpTiffFileName,"/var/log/hp/hpliptiffXXXXXX",sizeof(hpTiffFileName));
-        fdTiff = mkstemp (hpTiffFileName);
-        if (fdTiff < 0)
-        {
-            BUG("ERROR: Unable to open Fax output file - %s for writing\n", hpTiffFileName);
-            return 1;
-        }
+        BUG("ERROR: Unable to open Fax output file - %s for writing\n", hpTiffFileName);
+        return 1;
     }
 
     memset (szFileHeader, 0, sizeof (szFileHeader));
@@ -646,7 +645,7 @@ int main (int argc, char **argv)
     int                 fd = 0;
     int                 fdFax = -1;
     int i = 0;
-    FILE                *fdTiff;
+    FILE                *pFilePtrFax;
     cups_raster_t       *cups_raster;
     ppd_file_t          *ppd;
     ppd_attr_t          *attr;
@@ -677,18 +676,14 @@ int main (int argc, char **argv)
          i++;
     }
 
+    snprintf(hpFileName,sizeof(hpFileName),"%s/hplipfaxLog_XXXXXX","/var/log/hp/tmp");
 
-    fdFax = mkstemp (hpFileName);
+//    fdFax = mkstemp (hpFileName);
+    fdFax = createTempFile(hpFileName, &pFilePtrFax);
     if (fdFax < 0)
     {
-        DBG ("Warning: Unable to open Fax output file - %s for writing,so trying another location.\n", hpFileName);
-        strncpy(hpFileName,"/var/log/hp/hplipfaxLog_XXXXXX",sizeof(hpFileName));
-        fdFax = mkstemp (hpFileName);
-        if (fdFax < 0)
-        {
-            BUG ("ERROR: Unable to open Fax output file - %s for writing\n", hpFileName);
-            return 1;
-        }
+         BUG ("ERROR: Unable to open Fax output file - %s for writing\n", hpFileName);
+         return 1;
     }
 
     /*********** MAIN ***********/
