@@ -53,6 +53,7 @@
 #endif
 #include "hpip.h"
 #include "hpijsfax.h"
+#include "utils.h"
 
 int hpijsfax_status_cb (void *status_cb_data, IjsServerCtx *ctx, IjsJobId job_id)
 {
@@ -236,7 +237,7 @@ int hpijsfax_get_cb (void *get_cb_data, IjsServerCtx *ctx, IjsJobId job_id,
 	}
 	else if (!strcmp (key, "ColorSpace"))
 	{
-		return snprintf (value_buf, value_size, pFaxStruct->ph.cs);
+	  return snprintf (value_buf, value_size, "%s", pFaxStruct->ph.cs);
 	}
 	else if (!strcmp (key, "PageImageFormat"))
 	{
@@ -269,19 +270,23 @@ int hpijsFaxServer (int argc, char **argv)
 	IP_XFORM_SPEC	xForm[3];
 	IP_IMAGE_TRAITS	traits;
 	IP_HANDLE		hJob;
+	 FILE *pFilePtrFax;
 
-	char					hpFileName[] = "/tmp/hplipfaxXXXXXX";
+	char					hpFileName[64]; 
 	int					fdFax = -1;
 	BYTE					szFileHeader[68];
 	BYTE					szPageHeader[64];
 	BYTE					*p;
 	unsigned	int			uiPageNum = 0;
 
+	snprintf(hpFileName,sizeof(hpFileName),"%s/hplipfaxXXXXXX","/var/log/hp/tmp");
+
+
 	pFaxStruct = new HPIJSFax ();
 
 	if (pFaxStruct == NULL)
 	{
-	    bug ("unable to allocate HPIJSFax\n");
+	    BUG ("unable to allocate HPIJSFax\n");
 		exit (0);
 	}
 
@@ -290,7 +295,7 @@ int hpijsFaxServer (int argc, char **argv)
 	ctx = ijs_server_init ();
 	if (ctx == NULL)
 	{
-        bug ("unable to init hpijs server\n");
+        BUG ("unable to init hpijs server\n");
         goto BUGOUT;
     }
 
@@ -304,7 +309,7 @@ int hpijsFaxServer (int argc, char **argv)
 	{
 		if ((ret = ijs_server_get_page_header(ctx, &pFaxStruct->ph)) < 0)
 		{
-			bug("unable to read client data err=%d\n", ret);
+			BUG("unable to read client data err=%d\n", ret);
 			goto BUGOUT;
 		}
 
@@ -313,10 +318,11 @@ int hpijsFaxServer (int argc, char **argv)
 		    pFaxStruct->SetFirstRaster (0);
 			if (fdFax == -1)
 			{
-				fdFax = mkstemp (hpFileName);
+//				fdFax = mkstemp (hpFileName);
+				fdFax = createTempFile(hpFileName, &pFilePtrFax);
 				if (fdFax < 0)
 				{
-					bug ("Unable to open Fax output file - %s for writing\n", hpFileName);
+					BUG ("Unable to open Fax output file - %s for writing\n", hpFileName);
 					goto BUGOUT;
 				}
 
@@ -344,7 +350,7 @@ int hpijsFaxServer (int argc, char **argv)
 		}
 
 		width = (((pFaxStruct->ph.width + 7) >> 3)) << 3;
-        int widthMMR = width;
+        widthMMR = width;
 
 /*
  *      Devices in the HPFax2 category require fixed width of 2528 pixels.
@@ -358,7 +364,7 @@ int hpijsFaxServer (int argc, char **argv)
 
 		if ((pThisScanLine = (LPBYTE) malloc (width * 3)) == NULL)
 		{
-			bug ("unable to allocate pThisScanLine buffer size = %d: %m\n", width * 3);
+			BUG ("unable to allocate pThisScanLine buffer size = %d: %m\n", width * 3);
 			goto BUGOUT;
 		}
 
@@ -373,7 +379,7 @@ int hpijsFaxServer (int argc, char **argv)
 		pInputBuf = (LPBYTE) malloc (iInputBufSize);
 		if (pInputBuf == NULL)
 		{
-			bug ("Unable to allocate pInputBuf, size = %d\n", iInputBufSize);
+			BUG ("Unable to allocate pInputBuf, size = %d\n", iInputBufSize);
 			goto BUGOUT;
 		}
 		memset (pInputBuf, 0xFF, iInputBufSize);
@@ -382,7 +388,7 @@ int hpijsFaxServer (int argc, char **argv)
 		{
 			if ((n = ijs_server_get_data (ctx, (char *) pThisScanLine, pFaxStruct->ph.width * 3)) < 0)
 			{
-				bug ("ijs_server_get_data failed\n");
+				BUG ("ijs_server_get_data failed\n");
 				break;    /* error */
 			}
 			if (pFaxStruct->GetColorMode () == HPLIPFAX_MONO)
@@ -404,7 +410,7 @@ int hpijsFaxServer (int argc, char **argv)
 		pbOutputBuf = (LPBYTE) malloc (iInputBufSize);
 		if (pbOutputBuf == NULL)
 		{
-			bug ("unable to allocate pbOutputBuf,  buffer size = %d\n", iInputBufSize);
+			BUG ("unable to allocate pbOutputBuf,  buffer size = %d\n", iInputBufSize);
 		    goto BUGOUT;
 		}
 		memset (pbOutputBuf, 0xFF, iInputBufSize);
@@ -454,7 +460,7 @@ int hpijsFaxServer (int argc, char **argv)
 
 		if (wResult != IP_DONE)
 		{
-			bug ("ipOpen failed: wResult = %x\n", wResult);
+			BUG ("ipOpen failed: wResult = %x\n", wResult);
 			goto BUGOUT;
 		}
 		traits.iBitsPerPixel = 8;
@@ -468,7 +474,7 @@ int hpijsFaxServer (int argc, char **argv)
 		wResult = ipSetDefaultInputTraits (hJob, &traits);
 		if (wResult != IP_DONE)
 		{
-			bug ("ipSetDefaultInputTraits failed: wResult = %x\n", wResult);
+			BUG ("ipSetDefaultInputTraits failed: wResult = %x\n", wResult);
 			wResult = ipClose (hJob);
 			goto BUGOUT;
 		}
@@ -481,11 +487,11 @@ int hpijsFaxServer (int argc, char **argv)
 
 		if (wResult == IP_FATAL_ERROR)
 		{
-		    bug ("ipConvert failed, wResult = %d\n", wResult);
+		    BUG ("ipConvert failed, wResult = %d\n", wResult);
             goto BUGOUT;
 		}
 #if 0
-		bug ("dwInputAvail = %d dwInputUsed = %d dwOutputUsed = %d\n",
+		BUG ("dwInputAvail = %d dwInputUsed = %d dwOutputUsed = %d\n",
 		     dwInputAvail, dwInputUsed, dwOutputUsed);
 #endif
 		wResult = ipClose (hJob);
@@ -591,7 +597,7 @@ BUGOUT:
 }
 
 // GrayLevel = (5/16)R + (9/16)G + (2/16)B
-#define RGB2BW(r, g, b) (BYTE) ((((r << 2) + r + (g << 3) + g + b << 1) >> 4))
+#define RGB2BW(r, g, b) (BYTE) (((r << 2) + r + (g << 3) + g + (b << 1)) >> 4)
 
 void RGB2Gray (BYTE *pRGBData, int iNumPixels, BYTE *pGData)
 {
@@ -600,7 +606,7 @@ void RGB2Gray (BYTE *pRGBData, int iNumPixels, BYTE *pGData)
 	BYTE	*pOut = pGData;
 	for (i = 0; i < iNumPixels; i++, pIn += 3)
 	{
-	    *pOut++ = RGB2BW ((unsigned short) *pIn, (unsigned short) *(pIn+1), (unsigned short) *(pIn+2));
+	    *pOut++ = RGB2BW ((unsigned short) *pIn, (unsigned short) pIn[1], (unsigned short) pIn[2]);
 	}
 }
 
