@@ -220,7 +220,13 @@ Job::~Job()
     // we may need to eject a page now.
     if (DataSent)
     {
+        MediaSource     mSource = thePrintContext->GetMediaSource ();
+        if (mSource == sourceBanner)
+        {
+            thePrintContext->SetMediaSource (sourceTrayAuto);
+        }
         newpage();
+        thePrintContext->SetMediaSource (mSource);
     }
 
 
@@ -495,22 +501,29 @@ DRIVER_ERROR Job::newpage()
 
     sendrasters();     // flush pipeline
 
-
-    err = pHead->FormFeed();
-    ERRCHECK;
-
-    // reset vertical cursor counter
-    if (thePrinter->UseGUIMode(thePrintContext->CurrentMode) &&
-        ((int) (thePrintContext->PrintableStartY () * 100)) != 0)
-    // DJ895 in GUImode doesn't accept top-margin setting, so we use CAP for topmargin
-    // Start at the top for full-bleed printing - PhotoSmart 100 for now
-    {
-        CAPy = thePrintContext->GUITopMargin();
-    }
-    else
+    if ((thePrintContext->GetMediaSource ()) == sourceBanner)
     {
         CAPy = 0;
     }
+    else
+    {
+        err = pHead->FormFeed();
+        ERRCHECK;
+
+        // reset vertical cursor counter
+        if (thePrinter->UseGUIMode(thePrintContext->CurrentMode) &&
+            ((int) (thePrintContext->PrintableStartY () * 100)) != 0)
+        // DJ895 in GUImode doesn't accept top-margin setting, so we use CAP for topmargin
+        // Start at the top for full-bleed printing - PhotoSmart 100 for now
+        {
+            CAPy = thePrintContext->GUITopMargin();
+        }
+        else
+        {
+            CAPy = 0;
+        }
+    }
+
     skipcount = RowsInput = 0;
     fcount = 0;
 
@@ -531,6 +544,26 @@ DRIVER_ERROR Job::newpage()
     return NO_ERROR;
 } //newpage
 
+/*!
+This method forces the associated printer to flush the remaining buffered
+data and tells it that the job is ended.
+
+Calling this method is not mandatory, since the object destructor already
+performs this action. It may be required, however, if the destructor is not
+called for some reason (for instance, when the call depends on the execution
+of a "finalize" method of a Java wrapper.
+*/
+
+DRIVER_ERROR Job::Flush()
+{
+    if(thePrinter)
+    {
+        BYTE temp = 0;
+        thePrinter->EndJob = TRUE;  // the Job is done -
+        return thePrinter->Send(&temp,0);  // call Send to dump any buffered data
+    }//end if
+    return NO_PRINTER_SELECTED;
+}
 
 /*!
 Resets counters, flushes buffers, and sends a form feed to the printer.
@@ -827,7 +860,7 @@ DRIVER_ERROR Job::Configure()
 			   // VIP black data is 1 bit here
 			   unsigned int SeedBufferSize;
 			   SeedBufferSize = width;
-			   pBlackPlaneCompressor = thePrinter->CreateBlackPlaneCompressor(SeedBufferSize);
+			   pBlackPlaneCompressor = thePrinter->CreateBlackPlaneCompressor(SeedBufferSize, TRUE);
 			   NEWCHECK(pBlackPlaneCompressor);
 			   err = pBlackPlaneCompressor->constructor_error;
 			   ERRCHECK;
