@@ -23,6 +23,7 @@
 import socket
 import operator
 import commands
+import signal
 
 # Local
 from base.g import *
@@ -30,9 +31,7 @@ from base import device, utils, models, pkit
 from prnt import cups
 from base.codes import *
 from ui_utils import *
-#from installer import core_install
-from installer.core_install import CoreInstall,\
-                                   MODE_CHECK
+from installer import pluginhandler
 
 # Qt
 from PyQt4.QtCore import *
@@ -139,6 +138,13 @@ class PasswordDialog(QDialog):
         return qApp.translate("SetupDialog",s,c)
 
 
+def FailureMessageUI(prompt):
+    try:	
+        dlg = PasswordDialog(prompt, None)
+        FailureUI(dlg, prompt)
+    finally:
+        pass
+
 
 def showPasswordUI(prompt, userName=None, allowUsernameEdit=True):
     try:	
@@ -202,6 +208,7 @@ class SetupDialog(QDialog, Ui_Dialog):
         self.connect(self.BackButton, SIGNAL("clicked()"), self.BackButton_clicked)
         self.connect(self.NextButton, SIGNAL("clicked()"), self.NextButton_clicked)
         self.connect(self.ManualGroupBox,  SIGNAL("clicked(bool)"),  self.ManualGroupBox_clicked)
+        signal.signal(signal.SIGINT, signal.SIG_DFL)
 
         if self.remove:
             self.initRemovePage()
@@ -537,8 +544,19 @@ class SetupDialog(QDialog, Ui_Dialog):
                     else: # DEVICE_DESC_ALL
                         filter_dict = {}
 
+                    if self.bus == 'usb':
+                        try:
+                            from base import smart_install
+                        except ImportError:
+                            log.error("Failed to Import smart_install.py from base")
+                        else:   #if no Smart Install device found, ignores.
+                            QApplication.restoreOverrideCursor()
+                            smart_install.disable(GUI_MODE, 'qt4')
+                            QApplication.setOverrideCursor(QCursor(Qt.WaitCursor))
+
                     self.devices = device.probeDevices([self.bus], self.timeout, self.ttl,
                                                        filter_dict, self.search, net_search=net_search_type)
+
         finally:
             QApplication.restoreOverrideCursor()
 
@@ -652,17 +670,17 @@ class SetupDialog(QDialog, Ui_Dialog):
 
     def showAddPrinterPage(self):
         # Install the plugin if needed...
-        core = CoreInstall(MODE_CHECK)
+        pluginObj = pluginhandler.PluginHandle()
         plugin = self.mq.get('plugin', PLUGIN_NONE)
         plugin_reason = self.mq.get('plugin-reason', PLUGIN_REASON_NONE)
         if plugin > PLUGIN_NONE:
 
-            if core.check_for_plugin() != PLUGIN_INSTALLED:
+            if pluginObj.getStatus() != pluginhandler.PLUGIN_INSTALLED:
                 ok, sudo_ok = pkit.run_plugin_command(plugin == PLUGIN_REQUIRED, plugin_reason)
                 if not sudo_ok:
                     FailureUI(self, self.__tr("<b>Unable to find an appropriate su/sudo utiltity to run hp-plugin.</b><p>Install kdesu, gnomesu, or gksu.</p>"))
                     return
-                if not ok or core.check_for_plugin() != PLUGIN_INSTALLED:
+                if not ok or pluginObj.getStatus() != pluginhandler.PLUGIN_INSTALLED:
                     if plugin == PLUGIN_REQUIRED:
                         FailureUI(self, self.__tr("<b>The printer you are trying to setup requires a binary driver plug-in and it failed to install.</b><p>Please check your internet connection and try again.</p><p>Visit <u>http://hplipopensource.com</u> for more infomation.</p>"))
                         return
@@ -740,17 +758,7 @@ class SetupDialog(QDialog, Ui_Dialog):
         try:
             self.print_ppd = None
             self.ppds = cups.getSystemPPDs()
-            
-            #Check if common ppd name is already given in models.dat(This is needed because in case of devices having more than one derivatives
-            #will have diffrent model name strings in device ID, because of which we don't get the common ppd name for search)
-
-            ppd_name = self.mq.get('ppd-name',0)
-    
-            if ppd_name == 0:    #Means ppd-name is not provided So follow earlier path of getting name from device ID.
-            	model = cups.stripModel2(self.model)
-            	self.print_ppd = cups.getPPDFile2(model, self.ppds)
-            else:
-            	self.print_ppd = cups.getPPDFile2(ppd_name, self.ppds)
+            self.print_ppd = cups.getPPDFile2(self.mq, self.model, self.ppds)
             
         finally:
             QApplication.restoreOverrideCursor()
@@ -759,60 +767,19 @@ class SetupDialog(QDialog, Ui_Dialog):
     def findFaxPPD(self):
         QApplication.setOverrideCursor(QCursor(Qt.WaitCursor))
         try:
-            log.debug("Searching for fax PPD for model %s" % self.model)
-
-            if prop.hpcups_build:
-                if self.mq.get('fax-type', FAX_TYPE_NONE) == FAX_TYPE_MARVELL:
-                    fax_ppd_name = "HP-Fax3-hpcups" # Fixed width (2528 pixels) and 300dpi rendering
-                    nick = "HP Fax3 hpcups"
-                elif self.mq.get('fax-type', FAX_TYPE_NONE) == FAX_TYPE_SOAP or self.mq.get('fax-type', FAX_TYPE_NONE) == FAX_TYPE_LEDMSOAP:
-                    fax_ppd_name = "HP-Fax2-hpcups" # Fixed width (2528 pixels) and 300dpi rendering
-                    nick = "HP Fax2 hpcups"
-                elif self.mq.get('fax-type', FAX_TYPE_LEDM) == FAX_TYPE_LEDM:
-                    fax_ppd_name = "HP-Fax4-hpcups"# Fixed width (2528 pixels) and 300dpi rendering
-                    nick = "HP Fax4 hpcups"
-                else:
-                    fax_ppd_name = "HP-Fax-hpcups" # Standard
-                    nick = "HP Fax hpcups"
-
-            else: # hpijs
-                if self.mq.get('fax-type', FAX_TYPE_NONE) == FAX_TYPE_MARVELL:
-                    fax_ppd_name = "HP-Fax3-hpijs" # Fixed width (2528 pixels) and 300dpi rendering
-                    nick = "HP Fax3 hpijs"
-                if self.mq.get('fax-type', FAX_TYPE_NONE) == FAX_TYPE_SOAP or self.mq.get('fax-type', FAX_TYPE_NONE) == FAX_TYPE_LEDMSOAP:
-                    fax_ppd_name = "HP-Fax2-hpijs" # Fixed width (2528 pixels) and 300dpi rendering
-                    nick = "HP Fax2 hpijs"
-                if self.mq.get('fax-type', FAX_TYPE_NONE) == FAX_TYPE_LEDM:
-                    fax_ppd_name = "HP-Fax4-hpijs" # Fixed width (2528 pixels) and 300dpi rendering
-                    nick = "HP Fax4 hpijs"
-                else:
-                    fax_ppd_name = "HP-Fax-hpijs" # Standard
-                    nick = "HP Fax hpijs"
-
-            ppds = []
-
-            for f in utils.walkFiles(sys_conf.get('dirs', 'ppd'), pattern="HP-Fax*.ppd*", abs_paths=True):
-                ppds.append(f)
-
-            for f in ppds:
-                if f.find(fax_ppd_name) >= 0 and cups.getPPDDescription(f) == nick:
-                    self.fax_ppd = f
-                    self.fax_setup_ok = True
-                    log.debug("Found fax PPD: %s" % f)
-                    break
+            self.fax_ppd, fax_ppd_name, nick = cups.getFaxPPDFile(self.mq, self.model)
+            if self.fax_ppd:
+                self.fax_setup_ok = True
             else:
-                self.fax_ppd = None
                 self.fax_setup_ok = False
                 FailureUI(self, self.__tr("<b>Unable to locate the HPLIP Fax PPD file:</b><p>%1.ppd.gz</p><p>Fax setup has been disabled.").arg(fax_ppd_name))
                 self.fax_setup = False
                 self.SetupFaxGroupBox.setChecked(False)
                 self.SetupFaxGroupBox.setEnabled(False)
-
         finally:
             QApplication.restoreOverrideCursor()
 
 
-
     def setDefaultPrinterName(self):
         self.installed_print_devices = device.getSupportedCUPSDevices(['hp'])
         log.debug(self.installed_print_devices)
@@ -1005,8 +972,8 @@ class SetupDialog(QDialog, Ui_Dialog):
                 self.printer_name not in self.installed_print_devices[self.device_uri]:
 
                 QApplication.restoreOverrideCursor()
-                if os.geteuid!=0 and utils.addgroup()!=[]:
-                    FailureUI(self, self.__tr("<b>Printer queue setup failed. Could not connect to CUPS Server</b><p>Is user added to %s group(s)" %utils.list_to_string(utils.addgroup())))
+                if os.geteuid!=0 and utils.get_cups_systemgroup_list()!=[]:
+                    FailureUI(self, self.__tr("<b>Printer queue setup failed. Could not connect to CUPS Server</b><p>Is user added to %s group(s)" %utils.list_to_string(utils.get_cups_systemgroup_list())))
             else:
                 # sending Event to add this device in hp-systray
                 utils.sendEvent(EVENT_CUPS_QUEUES_CHANGED,self.device_uri, self.printer_name)
@@ -1258,10 +1225,10 @@ class SetupDialog(QDialog, Ui_Dialog):
             self.print_desc = unicode(self.PrinterDescriptionLineEdit.text()).encode('utf8')
             self.print_location = unicode(self.PrinterLocationLineEdit.text()).encode('utf8')
             self.fax_setup = self.SetupFaxGroupBox.isChecked()
-            self.fax_desc = unicode(self.FaxDescriptionLineEdit.text()).encode('utf8')
-            self.fax_location = unicode(self.FaxLocationLineEdit.text()).encode('utf8')
-            self.fax_name_company = unicode(self.NameCompanyLineEdit.text()).encode('utf8')
-            self.fax_number = unicode(self.FaxNumberLineEdit.text()).encode('utf8')
+            self.fax_desc = unicode(self.FaxDescriptionLineEdit.text())
+            self.fax_location = unicode(self.FaxLocationLineEdit.text())
+            self.fax_name_company = unicode(self.NameCompanyLineEdit.text())
+            self.fax_number = unicode(self.FaxNumberLineEdit.text())
             self.addPrinter()
 
         elif p == PAGE_REMOVE:
@@ -1271,8 +1238,8 @@ class SetupDialog(QDialog, Ui_Dialog):
                     item = self.RemoveDevicesTableWidget.item(row, 1)
                     printer = unicode(item.data(Qt.UserRole).toString()).encode('utf-8')
                     log.debug("Removing printer: %s" % printer)
-                    if cups.delPrinter(printer) == 0 and os.geteuid!=0 and utils.addgroup()!=[]:
-                            FailureUI(self, self.__tr("<b>Unable to delete printer queue. Could not connect to CUPS Server</b><p>Is user added to %s group(s)" %utils.list_to_string(utils.addgroup())))
+                    if cups.delPrinter(printer) == 0 and os.geteuid!=0 and utils.get_cups_systemgroup_list()!=[]:
+                            FailureUI(self, self.__tr("<b>Unable to delete printer queue. Could not connect to CUPS Server</b><p>Is user added to %s group(s)" %utils.list_to_string(utils.get_cups_systemgroup_list())))
             self.close()
 
         else:
